TownsNet
=========

.. logo-start

.. figure:: https://i.ibb.co/HHFSbqy/townsnet.png
   :alt: BlocksNet logo

.. logo-end

|PythonVersion| |Black|


**Townsnet** is a library to model a region of cities to access provision of urban services.

.. .. |Documentation Status| image:: https://readthedocs.org/projects/blocknet/badge/?version=latest
..    :target: https://blocknet.readthedocs.io/en/latest/?badge=latest
.. |PythonVersion| image:: https://img.shields.io/badge/python-3.10-blue
   :target: https://pypi.org/project/blocksnet/
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
